@@ -1,9 +1,11 @@
 package Class::Constant;
+$Class::Constant::VERSION = '0.07';
+# ABSTRACT: Build constant classes
 
 use warnings;
 use strict;
 
-our $VERSION = '0.06';
+use Scalar::Util qw(looks_like_number);
 
 my %ordinal_for_data;
 my %data_by_ordinal;
@@ -36,20 +38,20 @@ sub import {
             $data{object} = \do { my $x = $data{ordinal} };
 
             $data{value} = $value;
-            $value++;
+            $value++ if looks_like_number($value);
 
             next;
         }
 
         if (ref $arg eq "HASH") {
             $data{methods} = $value = $arg;
-            $value++;
+            $value++ if looks_like_number($value);
 
             next;
         }
 
         $data{value} = $value = $arg;
-        $value++;
+        $value++ if looks_like_number($value);
     }
 
     if (exists $data{name}) {
@@ -143,6 +145,10 @@ sub AUTOLOAD {
 
 __END__
 
+=encoding UTF-8
+
+=for markdown [![Build Status](https://secure.travis-ci.org/robn/Class-Constant.png)](http://travis-ci.org/robn/Class-Constant)
+
 =head1 NAME
 
 Class::Constant - Build constant classes
@@ -341,6 +347,10 @@ probably not defined; check your declarations.
 
 Robert Norris E<lt>rob@eatenbyagrue.orgE<gt>
 
+=head1 REPOSITORY
+
+L<https://github.com/robn/Class-Constant>
+
 =head1 COPYRIGHT
 
 Copyright (c) 2006-2010 Robert Norris. This program is free software; you can
